Skip to main content
summaryrefslogtreecommitdiffstats
path: root/tests
diff options
context:
space:
mode:
authorSzymon Brandys2010-09-20 10:08:45 +0000
committerSzymon Brandys2010-09-20 10:08:45 +0000
commitebfd74728cd433831142bce6ea76ac06a4a31a98 (patch)
tree09117c2afe03b108a81267fa5a6874e7bf4b6dc0 /tests
parent9670f56534855ab4121e34cd67f03cd9a6578234 (diff)
downloadeclipse.platform.team-ebfd74728cd433831142bce6ea76ac06a4a31a98.tar.gz
eclipse.platform.team-ebfd74728cd433831142bce6ea76ac06a4a31a98.tar.xz
eclipse.platform.team-ebfd74728cd433831142bce6ea76ac06a4a31a98.zip
bug 323378 - [Net] Native bypass for "*.eclipse.org" does not work
Diffstat (limited to 'tests')
-rw-r--r--tests/org.eclipse.core.tests.net/src/org/eclipse/core/tests/net/SystemProxyTest.java18
1 files changed, 15 insertions, 3 deletions
diff --git a/tests/org.eclipse.core.tests.net/src/org/eclipse/core/tests/net/SystemProxyTest.java b/tests/org.eclipse.core.tests.net/src/org/eclipse/core/tests/net/SystemProxyTest.java
index c8ac16585..fed53d922 100644
--- a/tests/org.eclipse.core.tests.net/src/org/eclipse/core/tests/net/SystemProxyTest.java
+++ b/tests/org.eclipse.core.tests.net/src/org/eclipse/core/tests/net/SystemProxyTest.java
@@ -1,5 +1,5 @@
/*******************************************************************************
- * Copyright (c) 2008 IBM Corporation and others.
+ * Copyright (c) 2008, 2010 IBM Corporation and others.
* All rights reserved. This program and the accompanying materials
* are made available under the terms of the Eclipse Public License v1.0
* which accompanies this distribution, and is available at
@@ -195,8 +195,8 @@ public class SystemProxyTest extends TestCase {
/**
* This test needs Windows IE settings manually set. See
* {@link #initializeTestProxyData()} for values. Additionally set
* <code>"eclipse.*;nonexisting.com;"</code> as proxy bypass in the IE
* settings.
*
* @throws URISyntaxException
*/
@@ -213,6 +213,18 @@ public class SystemProxyTest extends TestCase {
proxiesData = getProxyManager().select(
new URI("http://nonexisting.com"));
assertEquals(0, proxiesData.length);
+
+ proxiesData = getProxyManager().select(
+ new URI("http://www.eclipse.org"));
+ assertEquals(0, proxiesData.length);
+
+ proxiesData = getProxyManager().select(
+ new URI("http://www.myDomain.com"));
+ assertEquals(0, proxiesData.length);
+
+ proxiesData = getProxyManager().select(
+ new URI("http://www.test.edu"));
+ assertEquals(0, proxiesData.length);
}
private void initializeTestProxyData(String proxyDataSource) {
@@ -195,8 +195,8 @@ public class SystemProxyTest extends TestCase {
* This test needs Windows IE settings manually set. See
* {@link #initializeTestProxyData()} for values. Additionally set
- * <code>"eclipse.*;nonexisting.com;"</code> as proxy bypass in the IE
- * settings.
+ * <code>"eclipse.*;nonexisting.com;*.eclipse.org;www.*.com;*.test.*"</code>
+ * as proxy bypass in the IE settings.
*
* @throws URISyntaxException

Back to the top